from graphene_django import DjangoObjectType

from aleksis.apps.alsijil.models import ExtraMark
from aleksis.core.schema.base import OptimisticResponseTypeMixin, PermissionsTypeMixin, DjangoFilterMixin, \
    BaseBatchCreateMutation, BaseBatchDeleteMutation, BaseBatchPatchMutation


class ExtraMarkType(
    OptimisticResponseTypeMixin,
    PermissionsTypeMixin,
    DjangoFilterMixin,
    DjangoObjectType,
):
    class Meta:
        model = ExtraMark
        fields = (
            "id",
            "short_name",
            "name",
            "colour_fg",
            "colour_bg",
            "show_in_coursebook"
        )

class ExtraMarkBatchCreateMutation(BaseBatchCreateMutation):
    class Meta:
        model = ExtraMark
        fields = ("short_name", "name", "colour_fg", "colour_bg", "show_in_coursebook")
        optional_fields = ("name",)
        permissions = ("alsijil.create_extra_mark",)  # FIXME


class ExtraMarkBatchDeleteMutation(BaseBatchDeleteMutation):
    class Meta:
        model = ExtraMark
        permission_required = "alsijil.delete_extra_mark"  # FIXME


class ExtraMarkBatchPatchMutation(BaseBatchPatchMutation):
    class Meta:
        model = ExtraMark
        fields = ("id", "short_name", "name", "colour_fg", "colour_bg", "show_in_coursebook")
        permissions = ("alsijil.change_extra_mark",)  # FIXME
