import graphene
from graphene_django import DjangoObjectType

from aleksis.apps.alsijil.models import ParticipationStatus, NewPersonalNote
from aleksis.apps.alsijil.schema.personal_note import PersonalNoteType
from aleksis.core.schema.base import (
    BaseBatchPatchMutation,
    DjangoFilterMixin,
    OptimisticResponseTypeMixin,
    PermissionsTypeMixin,
)


class ParticipationStatusType(
    OptimisticResponseTypeMixin,
    PermissionsTypeMixin,
    DjangoFilterMixin,
    DjangoObjectType,
):
    class Meta:
        model = ParticipationStatus
        fields = (
            "id",
            "person",
            "absence_reason",
            "related_documentation",
            "base_absence",
        )

    extra_mark_notes = graphene.List(PersonalNoteType)
    note_notes = graphene.List(PersonalNoteType)

    @staticmethod
    def resolve_extra_mark_notes(root: ParticipationStatus, info, **kwargs):
        return NewPersonalNote.objects.filter(
            person=root.person,
            documentation=root.related_documentation,
            extra_mark__isnull=False,
        )
    @staticmethod
    def resolve_note_notes(root: ParticipationStatus, info, **kwargs):
        return NewPersonalNote.objects.filter(
            person=root.person,
            documentation=root.related_documentation,
            note__isnull=False,
        )


class ParticipationStatusBatchPatchMutation(BaseBatchPatchMutation):
    class Meta:
        model = ParticipationStatus
        fields = ("id", "absence_reason")  # Only the reason can be updated after creation
        permissions = ("alsijil.change_participation_status",)  # FIXME
        return_field_name = "participationStatuses"
